@@ -1,5 +1,5 @@
 package Dist::Zilla::PluginBundle::RJBS;
-$Dist::Zilla::PluginBundle::RJBS::VERSION = '0.100890';
+$Dist::Zilla::PluginBundle::RJBS::VERSION = '0.100910';
 # ABSTRACT: BeLike::RJBS when you build your dists
 
 use Moose;
@@ -44,13 +44,15 @@ sub bundle_config {
   my @extra = map {[ "$section->{name}/$_->[0]" => "$prefix$_->[0]" => $_->[1] ]}
   (
     [ AutoPrereq  => {} ],
-    [
-      AutoVersion => {
-        major     => $major_version,
-        format    => $version_format,
-        time_zone => 'America/New_York',
-      }
-    ],
+    ($arg->{manual_version} ? () :
+      [
+        AutoVersion => {
+          major     => $major_version,
+          format    => $version_format,
+          time_zone => 'America/New_York',
+        }
+      ]
+    ),
     [ MetaConfig   => { } ],
     [ MetaJSON     => { } ],
     [ NextRelease  => { } ],
@@ -83,7 +85,7 @@ Dist::Zilla::PluginBundle::RJBS - BeLike::RJBS when you build your dists
 
 =head1 VERSION
 
-version 0.100890
+version 0.100910
 
 =head1 DESCRIPTION
 
@@ -94,6 +96,7 @@ This is the plugin bundle that RJBS uses.  It is equivalent to:
   remove = PodVersion
   remove = PodCoverageTests
 
+  [AutoPrereq]
   [AutoVersion]
   [MetaConfig]
   [MetaJSON]
@@ -101,6 +104,10 @@ This is the plugin bundle that RJBS uses.  It is equivalent to:
   [PodWeaver]
   [Repository]
 
+If the C<task> argument is given to the bundle, PodWeaver is replaced with
+TaskWeaver.  If the C<manual_version> argument is given, AutoVersion is
+omitted.
+
 =head1 AUTHOR
 
   Ricardo Signes <rjbs@cpan.org>
